include/linux/hdlc.h
changeset 2 d1f6d8b6f81c
parent 0 aa628870c1d3
--- a/include/linux/hdlc.h	Thu Apr 09 12:06:38 2009 +0200
+++ b/include/linux/hdlc.h	Thu Apr 09 12:07:21 2009 +0200
@@ -43,7 +43,7 @@
 };
 
 
 /* Pointed to by dev->priv */
 typedef struct hdlc_device {
 	/* used by HDLC layer to take control over HDLC device from hw driver*/
 	int (*attach)(struct net_device *dev,
@@ -80,7 +80,7 @@
 
 static inline struct hdlc_device* dev_to_hdlc(struct net_device *dev)
 {
-	return dev->priv;
+	return netdev_priv(dev);
 }
 
 static __inline__ void debug_frame(const struct sk_buff *skb)
@@ -43,7 +43,7 @@
 
 
-/* Pointed to by dev->priv */
+/* Pointed to by netdev_priv(dev) */
 typedef struct hdlc_device {
 	/* used by HDLC layer to take control over HDLC device from hw driver*/